if( location.protocol === "file:" ) {
    $("body")
        .empty()
        .html(
            "<div><p>You are currently viewing the page from the filesystem. Unfortunately Vorple requires that the " +
            "page is viewed through the HTTP protocol, that is, you'll need to either upload it to the Internet or " +
            "install a local server.</p><p>See <a href=\"https://vorple-if.com/docs/localhost.html\"> Vorple's " +
            "Documentation</a> for more information.</p></div>");

    throw new Error( "Vorple can't be run from the filesystem" );
}

vorple.options = {
    container: "#vorple",
    autosave: false,
    engineColors: false,
    story : ""
};
vorple.debug.off();
vorple.init();

// TODO: New sigil files have to be added here!
copySigilFileToVorpleFileSystem("testbed2d");
copySigilFileToVorpleFileSystem("testbed3d");
copySigilFileToVorpleFileSystem("tutorial0");
copySigilFileToVorpleFileSystem("tutorial1");

vorple.addEventListener("expectCommand", scrollToLastInputListener);
window.addEventListener("beforeunload", showSaveWarning);
vorple.addEventListener("submitCommand", prepareSaveWarning);

let transcriptFileName = null;
vorple.file.transcriptFilePrompt = callback => {
    const choice = prompt("Please enter a filename");
    if (!choice) {
        return callback(null);
    }

    transcriptFileName = vorple.file.path(`quoll-transcript-${choice.replace("/", "-")}`, "/quoll");
    callback(vorple.file.path(choice, vorple.file.TRANSCRIPT_PATH));
};

// Replace the haven send function to intercept mouse events to prevent it from scrolling to the bottom upon clicking
havenSend = haven.input.keypress.send
haven.input.keypress.send = e => {
    const isClick = e instanceof MouseEvent;
    if (!isClick) {
        havenSend(e);
    }
    return;
};

async function copySigilFileToVorpleFileSystem(filename)
{
    await vorple.file.init();

    fetch(filename)
        .then(response => response.text())
        .then(content => vorple.file.write(filename, content, { header: false })); // Already has a header
}

function transcriptOn() {
    vorple.file.mkdir("quoll", { cwd: "/" });
    vorple.addEventListener(["expectCommand", "expectKeypress"], captureCommandsListener);
}

function transcriptOff() {
    vorple.removeEventListener(captureCommandsListener);
    vorple.addEventListener("expectCommand", setTranscriptLinkListener);
}

function captureCommandsListener(_) {
    writeLastInputToTranscript();
}

function writeLastInputToTranscript() {
    if (!transcriptFileName) {
        vorple.removeEventListener(captureCommandsListener);
        return;
    }

    let lastCommand = $(".lineinput.last").text();
    let lastResponse = $(".lineinput.last ~ *").text();
    vorple.file.write(transcriptFileName, lastCommand + "\r\n" + lastResponse, {
        append: true,
        header: false
    });
}

function setTranscriptLinkListener(_) {
    writeLastInputToTranscript();
    let transcriptContents = vorple.file.read(transcriptFileName);
    let transcriptFileNameOnly = transcriptFileName.split("/").pop();

    $(".transcriptionLink")
        .attr("href", "data:text/plain;charset=utf-8," + encodeURIComponent(transcriptContents))
        .attr("download", `${transcriptFileNameOnly}.txt`);

    vorple.removeEventListener(setTranscriptLinkListener);
}

function scrollToLastInputListener(_) {
    let previousTurn = $(".previous");
    let statusLine = $(".status-line-container");
    let header = $("header");
    if (previousTurn.length > 0 && statusLine.length > 0) {
        let previousOffset = previousTurn.offset();
        if (previousOffset) {
            let newOffset = previousOffset.top - statusLine.height()
            if (header.is(":visible")) {
                newOffset -= header.height();
            }

            let bodyElement = $([document.documentElement, document.body]);
            let bodyTop = bodyElement.scrollTop();
            if (newOffset < bodyTop) {
                vorple.removeEventListener(scrollToLastInputListener);

                let reshowPromptListenerAdded = false;
                bodyElement.animate({
                    scrollTop: newOffset
                }, {
                    duration: 1000,
                    complete: _ => {
                        if (!reshowPromptListenerAdded) {
                            $(window).on("scroll", reshowPromptListener);
                            reshowPromptListenerAdded = true;
                        }
                    }
                });
            }
        }
    }
}

function bottomInView(elementSelector) {
    let pageTop = $(window).scrollTop();
    let pageBottom = pageTop + $(window).height();
    let elementTop = $(elementSelector).offset().top;
    let elementBottom = elementTop + $(elementSelector).height();
    return pageBottom > elementBottom;
}

function reshowPromptListener(_) {
    if (bottomInView(".previous")) {
        $(window).off("scroll", reshowPromptListener);
        vorple.addEventListener("expectCommand", scrollToLastInputListener);
    }
}

let saveWarningShouldBeShown = false;

function prepareSaveWarning(_) {
    saveWarningShouldBeShown = true;
    vorple.removeEventListener("submitCommand", prepareSaveWarning);
}

function clearSaveWarning() {
    saveWarningShouldBeShown = false;
    vorple.addEventListener("submitCommand", prepareSaveWarning);
}

function showSaveWarning(e) {
    if (!saveWarningShouldBeShown) {
        return undefined;
    }

    // Won't actually get shown most likely, but just in case...
    const confirmationMessage = "Warning! ReckCo! DeusFilius detects an unSAVEd timeline. If you continue, this " +
        "timeline will be lost, returned into Chi Energy! Do you still wish to leave?";
    (e || window.event).returnValue = confirmationMessage;
    return confirmationMessage;

}