## Subresource Integrity

If you are loading Highlight.js via CDN you may wish to use [Subresource Integrity](https://developer.mozilla.org/en-US/docs/Web/Security/Subresource_Integrity) to guarantee that you are using a legimitate build of the library.

To do this you simply need to add the `integrity` attribute for each JavaScript file you download via CDN. These digests are used by the browser to confirm the files downloaded have not been modified.

```html
<script
  src="//cdnjs.cloudflare.com/ajax/libs/highlight.js/11.5.0/highlight.min.js"
  integrity="sha384-CiAaq0f1YknH0jmsIBV6I9ge1M4OtheoTPIMSwdSIVK+SsKiSyPuP2U052t4aXET"></script>
<!-- including any other grammars you might need to load -->
<script
  src="//cdnjs.cloudflare.com/ajax/libs/highlight.js/11.5.0/languages/go.min.js"
  integrity="sha384-V4w6kTKw8nsNWhp2tG2nD9gKtqMU9/Ma4R4GzbGuixxUtw63QRP1IUCWBaO9PiYS"></script>
```

The full list of digests for every file can be found below.

### Digests

```
sha384-CiAaq0f1YknH0jmsIBV6I9ge1M4OtheoTPIMSwdSIVK+SsKiSyPuP2U052t4aXET highlight.min.js
sha384-bI2liy+dOzSZSX+VT/3OWyArGp++nEYpa+XJ8Ml+iG5D0WpIdqi2heFEIoLUc5rC highlight.js
sha384-cnM7pOGswPhirkGGAh4Lu+Ok3l1qgwh+1kfQL0KDuUVgOs+KJIjOLJiLxfTlx13P es/highlight.min.js
sha384-NNWQUF/Tr9RYrO7oGqlBmj6+OcMPxWuXb8SeOMD1ruBdBYv6RyEUihWPZXElOV2n es/highlight.js
sha384-cnM7pOGswPhirkGGAh4Lu+Ok3l1qgwh+1kfQL0KDuUVgOs+KJIjOLJiLxfTlx13P es/core.min.js
sha384-NNWQUF/Tr9RYrO7oGqlBmj6+OcMPxWuXb8SeOMD1ruBdBYv6RyEUihWPZXElOV2n es/core.js
sha384-cZvDCyxCRbYUpC27Dcoa13WLYVM3TMmxwCnRSBrc+NROGA9uKn1hnqtZQOmR8WWr languages/abnf.min.js
sha384-k4etQZeII7KfEFS5hHsrGkZRNgv7AnF5MFt4AXW/fLntXH3OvXLYAVm3ch6a3J0T languages/accesslog.min.js
sha384-PYf1w2o7cTZi6QxatFB57HsZ+JzJnR4kEafW5P+4xaZvJeaT3aps+rMBImzndRqw languages/ada.min.js
sha384-bzEyUVJgNjsuqdJsrDdI2OwhGSOmxuvDxhv4RXFAy2U23cAKpF1VIigAkciK8K2B languages/actionscript.min.js
sha384-k7UDv6V0+k6lIkGvsSFkBv+MVHM9z1I2iidhDvFU43k8aE37m3CAZCvT8za2G4Ea languages/angelscript.min.js
sha384-yWGOXUwpfG/zcIdLq5dwHy3SZZ9IDe77tKbLviOrL/3fYz5gWuXPTFpNKoXYT+EJ languages/apache.min.js
sha384-SRf5kxkHDBimeEq6aCHrHid5bn0Uk1NGfB8/GZdk8Dpaw7V+xrR3KD+Ui7FTEwtS languages/applescript.min.js
sha384-p5bNJ4g+3NGS7IWvUMmVziYzW4IqeUR8D3Evc+lsgYoD0IdnUeMrzfCYnoz/gm3c languages/arcade.min.js
sha384-B4nqWXR9rC48nA/BiS+wwl41T28Yj1tGf8daJtFcdPDUhLUEWdtukGaLnciyVxKM languages/armasm.min.js
sha384-em+Kz7Lrv+4Xu0fIHNxl2hTUXQWBs5QPAZvJFWzZ3I69cTDMLekkGOYaS6Ydw/us languages/asciidoc.min.js
sha384-myPERbBPCmN0GgYcXtI4f3L1T17eTStAaZpJRfoP1/GegCnmOTIdgQAqDxMWyX18 languages/autohotkey.min.js
sha384-z1MIx8IyfKJTc8XB784oV3Ur3yYXKcna3CRuvD//OQgFjIv0r91YR6XrCFILXBYh languages/aspectj.min.js
sha384-rwk78EPbeUrAMGlSYurtWtm12QviPNVToJjAKedQflV8bH5Kp8AEmT8lch7RAX3h languages/avrasm.min.js
sha384-EBGdgM0JFiH0JRxwmo4VNqBGUFjKRHVoGr6nnLqY6/MvdUpmvYy3EW69ckcR7OnF languages/autoit.min.js
sha384-oWlhO2m7MWB0RMgWcdqQpS9n08s0R1am6KUBYQM4ZMUfHqmURiQts/V7ta+c/ahb languages/awk.min.js
sha384-AhJTBN2EVQaChx/3wrof5Q07QeJd7XCNXTMEiObDevwC7a3P/YKKT6F7+a4z3Y/S languages/axapta.min.js
sha384-G4YLA/6ObL3CXYQA6VveNf4bc1N6qOEFkr/jTIlJgfhCYbw6lgRMLsfzmRsSQG1D languages/bash.min.js
sha384-q5iFp0FEB1/ho+uZc5OgMUACX3KZmByfOD+auvCxHJS8VzUZFtkmjYaflRKNkijt languages/basic.min.js
sha384-tdKU5uH/qp2tpOnROkY1QEK4t4wvxRxjrZl7hc3LRl8jwR2aVhq+tUXeVnVuEbr7 languages/bnf.min.js
sha384-6qUovZcxVNKi32XRM+SXPonBscftYJRJghGrgmofXwvwqBVwDot9IpmmggMO9XgJ languages/brainfuck.min.js
sha384-NaTEx8glSOqNkyxcYPHIGff7aKBzOfe1X+wQKbr3X18sBN2HBriy66XRcLxG67xY languages/cal.min.js
sha384-v4H9Vdcs/0AwnAh13EahXtKdBgut6R58q5NroSdkRPdWSJsAMmmd/rIcyXlZ3/Bz languages/c.min.js
sha384-NWH5IVMhtH1/MuWohdzujZbL/arN5tjsgrF7SGBh+nYSwDTJLR4Dln4964spd+ao languages/capnproto.min.js
sha384-gemJQWBFkQEzUWQxgonZmdhwPeK6BFtoLhSRZqKZ9VvbY814vFlxsmCAPWXOfeo5 languages/ceylon.min.js
sha384-4bbn4jq+FyStrEOQW3Pv9BZU0YX/0/UVsjJG+HarpDCvBwuJjBvCKjBK2ME9cF+u languages/clean.min.js
sha384-WVKsduyNuo466vznjPrxHdN+rAY9W/Rn86O9JWtXio6N7vwvxJ0Z+F8wUr2SdAZI languages/clojure.min.js
sha384-g1L/3gVY2tVAQhQOm/9grpjaY7X8NvE6ZjDKHXEkDVcb35mPWoIxlwFfYyOMh+Aa languages/clojure-repl.min.js
sha384-TLe+dJOiNo1HLoC90hSExAiVaAsDNv3iAD8GpT2mcUxdj7goDGr3lSZs86jNLGSa languages/cmake.min.js
sha384-8/rMTie6slQ2M8gFFBqOXwYHpW4VzhKCB/xPDDme3rwAF70E9NTDe2d1WBZEH/hp languages/coq.min.js
sha384-TiijTU7ZJF/B6sxfsv9NUx2xH4PhVlX0rckKq8e2JjnAtDTGOQ5RIRDm0uTUTbA/ languages/cos.min.js
sha384-DEuu5VVWb1U+Yv896nfGKEqI4Of4hMWxAE2Vdd7UQZjATUY6pbLQ93+EZXf2rzDd languages/cpp.min.js
sha384-n0RFrKX0SJPe5QYCenysf8TdB4HIOoMBBsRlWA18DxOQwWEw4Bnm7H6TfCzIA4ui languages/crmsh.min.js
sha384-zgImRuJCvJ5uUzlH0QYcLrPTu+N4XPrvPYW6KWCY6/JxgtelZACln/7FzJh0gPL7 languages/crystal.min.js
sha384-CQ9iuA5kqcvMENE2FGjYRiDo2S7YCk/hhQfi04pBgm7ATNSPjRTVB0QZsQWAGez7 languages/csp.min.js
sha384-pRtrB/ElKsjvpTS4TOWTLbgcgS/YosfroWb9sDruJy4Ji5Q56LDKBTlBpCvbGQ2R languages/csharp.min.js
sha384-77Zd7PW7RSsfs1oEKBAhnwxTfmyCmtN4i9SPVf2z3a2gq+xLpdvgkCbwAg3vm6xs languages/d.min.js
sha384-PXhMTyjo7hM5IKH7tSZNBRrzwYuBqzmdmOQNNoiYip54mVh5O+zXCDiYd5owqVI5 languages/dart.min.js
sha384-v+eBhF53ncijrOsFfsK/QwH4SCkdoZey7Fu32WCJEJtg8+i0D7HoY8RPuKzc0Q3u languages/delphi.min.js
sha384-aTsKrdPfMT6UlhrUsl1HAd51cLI71/DSZ5NPs5PXNRl6dSNymH8XUiWiVhaHoF5j languages/diff.min.js
sha384-zxuyujKUQ7m0/lmVnqbYQuLiceyT9syhbnNXsfGy8Dr2J071nuF/2FQOkwVaurkr languages/django.min.js
sha384-eLTbXcr0AQob79h6NYjyARgEPEGemtZwwwzzgFkLskf0FuvFdskmTmImGUOuivkZ languages/dns.min.js
sha384-+E05SEReaFBKqt/NhL4bvgHtexBT9cmtfWU6TBbeDA5y0bwCdmaDzS8fCL2gkMXW languages/dos.min.js
sha384-azntapzuGS2kXFXbzD9WvX0NDRwfeprTA3NpcI7Vq0Y1iEWMplwWW4nTFLLBtFjY languages/dockerfile.min.js
sha384-09n+gCZCXlU3/Xp3QCj98m6DXyPBRcwagdwtWdHHl36gawgE207TrZ4RFrWhRQ+u languages/ebnf.min.js
sha384-38JtteF2gjCo/9IbVxHZjEHNxDH/FevhYu5UEpiGuk4v8KmF5oghTcNyMvRcox79 languages/elixir.min.js
sha384-0T7l3Lucb7gyZS5+YyyuQvpDGTSDC7DlbnzQPJ8EhuA+BRWeDGSNUX+JOIqwTH78 languages/elm.min.js
sha384-th+QuEmcCfsHz1MqzgmsJ6lnScW6Hb0+ZMKKqO81Oqb8hCfueKjr5onATDdV9S/J languages/dsconfig.min.js
sha384-ihwKEPFjGU4ENRoxTOYnzp+ljdB0t1rJOyMoI71EQvZgZmp+HByyG2OfrLuUtknF languages/erb.min.js
sha384-aJWfMwm7GY50+WFu0UY1qNCSpUTa7HfMQySOZRNZgPprxg3NQ7ZHZZ5sQf/dsNSw languages/erlang.min.js
sha384-tYhtoRXyvGhDIkwPpCE1+TN0RncNxPqJQou8jVlFODcAmYKPyrmLY14iJQmZL1Ay languages/erlang-repl.min.js
sha384-ao7Xorb3sodnBURo3C4HhkKJ9v8rr5tMtZzyVxG1FaT11URVmL44rWwytZNAnh3f languages/excel.min.js
sha384-0X18MC+lPIFm6txsGAACaSuN5aXMnYk2HVph8fKkzvHttIVkPDtHY4J72ecTKDqk languages/fix.min.js
sha384-reHebqMjccgTSeHe41oC3sq7QZB+nSkBSk5QCJ23nvEAjuFumdSKUTyCCS6xzsNg languages/fortran.min.js
sha384-1+0PT13oI8m5MRqCgQ82qIT+7r2Q+lDkRLZ0Bn2qqUzMuNPuqN/11ZLZJg3hfuoy languages/flix.min.js
sha384-7CYRH0FwYihZ3YcyJRTDNmrBwl3it5FjkFTrIFF3qPdS8CoGzgGZZZxgME6j3RCG languages/gams.min.js
sha384-22iGWS0cDMepHd+7RXaIypErZXofizEsThF2psuZ3h1jihJkCzq2RkXMqEU+Huc8 languages/gherkin.min.js
sha384-n/lVWh9kvFVQZxjDG/k4nZBiv50VsA4pi14mBUWaQURO06qA2EbuP5IQjyTHnfvl languages/gcode.min.js
sha384-vvQ6202LOP7iPgTK2GiqFvsO0IF6DdiYS697NbRv8dl44l2dFpME5jS3qeE4Bhrh languages/glsl.min.js
sha384-V4w6kTKw8nsNWhp2tG2nD9gKtqMU9/Ma4R4GzbGuixxUtw63QRP1IUCWBaO9PiYS languages/go.min.js
sha384-XQTYRVW8pIOhvgA0/CfX90+7UXd5p5o2yiJyBjuMfpUA0krcfEpFEiaLK4nCvRZ7 languages/gradle.min.js
sha384-yyVQZasW9KBH60+G2LUQ+CrRRhi7BFZd2/eq63StRQ+t3PnERRV3jDUDduU4oaZ8 languages/golo.min.js
sha384-keAIr/E5ri5cBrq4EyY6lmoHiNhkMR+1m3FfgvxTozh5uWjbrLIgcXRxknxwCSaf languages/graphql.min.js
sha384-3M/T2HmNsolOKuqWSXTGbslmTe08dmaZXxlhXcQFeuFCLtN15doXh1cUcXxUra/v languages/haml.min.js
sha384-Mkn5W4zTCzMAmoepnx+zAQv4rNEOscN8FOre5cdNB2bAJtqwXSSvnCdRJ9yblJTx languages/groovy.min.js
sha384-uyL1ZS7oL90ZhU9/Btr1guKHp1+JivkVADTfzLVMLIY+YEYZkRi7QsgB7heQHo18 languages/handlebars.min.js
sha384-cBvKr7uL7LnwvMEiYs8nlwreyns3lbu9mi2UhUr2saSEs+Ds9fk1G7+LcSAVWV4O languages/haskell.min.js
sha384-fKGbV92vBZMlr+/RLPxu5bbvjCuL0IoD0u8BEVQW5fiXYoEbOAjX3FPSAGOyQaMs languages/hsp.min.js
sha384-Mr6WUycNwD4ndon88MOpA4u1K8ld/oYm3RsyLCys8ZTav/rxEAjy3CqEFSD+Q0Lb languages/haxe.min.js
sha384-8zBvqvM0kI5qGVqVx7uvYFhjUCVTADUOOabD2F4j7zQg2Haji5N3eICHfYrvqdBU languages/http.min.js
sha384-3hwSucLkM6KbNwwx+eDusNMCaEq7BRA991hspKXKu9QL6Wqo5nv1apEUardPX6/7 languages/hy.min.js
sha384-CQp3WhBjxZgUDBJTzj5QAp2UgGgu7hEHwPSnPj7EB4FtpJo4Iy7YnPEZpaPJFNf/ languages/inform7.min.js
sha384-KG04BybfcPyJPAhuthQygdulCrwp2oZX6zfo9xq9/qLc51Kk6dxQinpvPg/jRpsQ languages/ini.min.js
sha384-s5T/oWn5PxFGe1ybPIseRnYhBppY9OZMzlxPdCfFNgNsOn+lrfVh3nvOLnwqLy8X languages/irpf90.min.js
sha384-r09N+MrM6d44cNaEcG9rIlCjnFPsaFhZq0K2Nzf4jsNefm3QDC95dtG+5R8nuH7B languages/jboss-cli.min.js
sha384-NJLxkNwSLnm7A33beTlJtpowtlUD+9aaSP6FlRCkjuNW68W+kGDRo63NngDg+smz languages/julia-repl.min.js
sha384-kUmSzBNoIwLrjF6i5MWIaD4SnP7vf/nCC3N0iBkRfugdvNcx0WJKCVmCL9nzuC23 languages/json.min.js
sha384-x7DYdUbr5biYXoKAXMfwmFyhRwkmz2Wv91tdYAJDBPlhkSBCDP6hZGnMf8vI1B0q languages/julia.min.js
sha384-4lQdtACx5cnxcGe8AiwkVv+Xy21tjobbrAlp4AXZVlet+hpTjYWk2dLlGZ16oY2O languages/latex.min.js
sha384-L+f+f8P10aQj4iAgLNtdDniPYSmDbiNE/xKvn0RHYhYR6tN12pa39YVgqxJKGlmp languages/lasso.min.js
sha384-q4Oh2CdZut7QvCaPhm+7C39fn+kykdlVHH62BD0boxv7Gww40vnjWWCSmxFJdRdg languages/ldif.min.js
sha384-39Pzlfun+9CKyDo73WgoudZpH1yp9XO4zNnTOEHuPKqwg3IyyfnTttp91WhMFONS languages/leaf.min.js
sha384-AVgzbLShjayYGaUyOifCEpm/36kJrDPRZltY6iEg5TLzcFnr4fhu3shZ02mynq1L languages/lisp.min.js
sha384-J5QwY8DzXnZ9w/t0TGbLkaY/TwctZb/YERiPdWh5E6rrSrBn6Y5Tf/rz+SkFoU6j languages/livecodeserver.min.js
sha384-WlHKTrOT+Sb5ugs4754d89FOeJykHQC4qVM/IrmivS48ULP4boV/bWZnTjuKZwWG languages/llvm.min.js
sha384-A2ztqP5Gvzit+mJvC4cKgZGf7h5zS0dFKmsJLTbyUHx4qcW7A5r5KpZDdPvMd9Dc languages/lsl.min.js
sha384-WzzFRL0/L9vl/+Slliys371boRHIuQy7l6upbAn+c4fOr4hsIoaB29t4qMQ4E9vR languages/lua.min.js
sha384-MtlY2aOhAkrCu6VYPeOuAig021768Ir0UWCnzcR6tonSqsIAWGr8PjOJs97J6SeM languages/makefile.min.js
sha384-TMvt6ogtFQE5yS0OWdp023W8suIN2+hrUENwSJNyg0+unzrTk41i3gMwLef9e2eV languages/markdown.min.js
sha384-t2jFYNpPbs3UzX3d0UhKZ+6Y69GnzW9HQezGckljZcGQKXdJGYekmaq+0pbSEo7V languages/matlab.min.js
sha384-SVljNyyV2JEprJE3KakHvIB2cpuwJg3Jif5f520/KIasIwPX2238iAbwukJjS3F9 languages/mercury.min.js
sha384-8YRxYR7Zj9GkK0wT12cN3iOf9wBpjPf83WxCpyACnjLr0rn+PqcJJKdeZDP/uLZG languages/mipsasm.min.js
sha384-+FGRRMS6UFOHowVFeMpB36gTSXxw87TQUlyqkqXBOM/Nd7luVeTKx9w9hpYnJCw5 languages/mizar.min.js
sha384-5Gqkzo+/2yGpAWPXcdPw3QA52kMOntmpvvNef16Q2ufV92DeqCNllsiZBotfD1BG languages/monkey.min.js
sha384-k1EFteKvzsJgWLH59q0bPUcir8CHfXTmTLbBTvYeqRAec6e2PSyzKclzENvwvguU languages/mojolicious.min.js
sha384-WI7ZgdtkAOA6/HiiCB98idb3SFqyj+15N7Xd0HJsEsq9aSnenNZ24sEvy6NoQL5o languages/moonscript.min.js
sha384-tRvCLe15WtTm4o1FZXc9ytIqpWKhbZgHS4SLPVaeZ/vg9cHVLNuFDywcV55bzmHr languages/nestedtext.min.js
sha384-WXVttpKQtnCEpws8XHuEVtCXS72UbtodEXxVnG/OdX1ia84SDWq6irsoAOI7e7IP languages/nginx.min.js
sha384-rTvS+fs989Go7qlIJad6ySvEFYLwR+akBWrhWbs+2WPI49gEtt0EsaJxCr2ApsuQ languages/n1ql.min.js
sha384-K/q4AkMEnkqHv8WH7nw9glpkUM3XibRzwrTcI6aHeo8PgFG8sJthRs8K43vCwJFW languages/nim.min.js
sha384-ZPd/Nd/30QhHt86JOu5mA0L6lpxGFwHF6od/u6FWovZyJx//m1Bb4Q3lmRvyAvHk languages/node-repl.min.js
sha384-+9XO/CcKHSjN66ahIt1TfctmL6x3QDVxuQUyiEUAUyX6E8hlCY02TQxMQeRCZJaz languages/nix.min.js
sha384-hEWFc+b02OVOMmpZHkhnvGc4PgmWnNeWLKWc4pmXxdidY24d0LOpnBfd9Oo+8QQg languages/objectivec.min.js
sha384-ahsecqTvnawqEpUzVdmi+Euzpz6Ua+ASb45fYTeB2leexkTOQc8AEhRsCvVbOFgn languages/ocaml.min.js
sha384-4o0239WRli1fO37CLWE1v/4Rm0jUQBqrmbsy/qMF+MaRWcdWSaF5j7ol2CWZOBhr languages/openscad.min.js
sha384-r3tm4LkPg0mnvn0AnisCvPEJB55ae+CvQyzyUz4S+VcTpCqKdGe6lSgw77jI/HlZ languages/oxygene.min.js
sha384-rzqv23R8pKOLp+PMj6E4QDHbimq5u40tZsQUc/exQx/7MJc6VUwbkrPGT52vWgWm languages/parser3.min.js
sha384-vreFaB2jvQ2YKO+uIXKQcZVZeFC5nyON6kg3SMDcF7lWISHe78yRV9en6W2K/RO3 languages/perl.min.js
sha384-Dj+NJfuJ5CXLFMKKptdm9Ccz+KNc0nA6aTq2t2WvJs7cGKWH2Fx1JD8E/v8KVoUi languages/pf.min.js
sha384-Ox6GfcFA845xDZEqNnBHwnrdO7T1dIDyl1WEH7e+Z1y8552aotZrJwQU629ekPUB languages/php-template.min.js
sha384-yAtgl9KJ65TrHN5m3i+E5Kuzu1JR3aB8kTPeR+o/zABJN/Ug3QPvCtmtwf8kHxaT languages/php.min.js
sha384-79Tis5mSd85aeCaK6hLAYTliv65UpQ10w9M+exfmidmEl76EtwbHwPi3Q9FrUWRf languages/plaintext.min.js
sha384-SjmTdotQOgM0ah1ljM8JebkcSJAkwWq9IaqxAqmf0polDZu8/Nu0KNk78NI9aVsK languages/pony.min.js
sha384-i0Hv8ajv5H2Bge0j7ixN4ze/L2T8XL/GE5CWCR497V0AolV/cl7RGajp12VoRWWe languages/processing.min.js
sha384-6Drcqq99yoF4F6wUGi8zyVSIT0RPtxtZClqFQqkncsFpSS9vM26bKHRZpE5K/1IJ languages/profile.min.js
sha384-t1VfHZdUrnNmOEZFRhc47zB8AlC8ktwhwDDgKiKBuZAndoYuRzCbewkou6nkAwTJ languages/prolog.min.js
sha384-zYkH0neDma9ExtpRRNM/5G145riAIK2HNhVLSKU4NTWvPwfgMDu0Q7/6gZHp72mD languages/properties.min.js
sha384-6zJrkcTpfwC0iI2DNPs4wRuaVr+M3C4Ta3AG8RxTjSAeQtotO2ZYDWFsLJ3elCHj languages/puppet.min.js
sha384-bwXXpTDQ6PBM0yTzzKhw+MzrvAEcoulav2mGbFKO8PA8ytbXCDlqhOQi4OsFeizM languages/protobuf.min.js
sha384-2sJrtcqd1byM4yH4cE9Xt2HOmLC881lxr6jhlggEIiIo40K+wdEYgnl2dSAgurxz languages/purebasic.min.js
sha384-xRkyXcPHo24AkiN0cWAhj5/+s5+aqqyO1bhuNAZoV7wJWPP6J1eMsmzIEbqmGsoU languages/python-repl.min.js
sha384-fKi6bzA5Yuhaa/M7JTWSgaMSPi1hp43TWFD8XcczMXoGfPWLJ0Qa9dDqW8apnP7y languages/python.min.js
sha384-lTkNapqHSBoutj/xWJkWoBWQgRStrExelGenZXYIy69VpTc8XcZrkW3ZYAQlgRFz languages/q.min.js
sha384-0RoDw7Lrbniip/O7WPft+tIEw3wyS3gg2c61kF38LNrQeeRCgLaCQ9gFd/W3JX7G languages/qml.min.js
sha384-I7rlK7QZfkm6F6oL7y4a5VPfLuamH9fhgooUJA6BDflby0IbtZbNKv4WEru+JU5/ languages/r.min.js
sha384-rAysVHgSeyBl2wiza0OB5OEg/Az2AFcB/dT+y1T6udWK42Mogunu4cnnFn739thy languages/reasonml.min.js
sha384-M3EM8cHX0p4/msxBhhKQb4+NUbR80v9IseJTjVVDqy/lQfCVXzmqpiNURbJUMG5J languages/rib.min.js
sha384-BywLwcWrYAPxBo9st1DLbSR66tkRGEdYFGHAmv46r4wQG0g0FpfhKzaWqPzBaB0h languages/roboconf.min.js
sha384-TVGms0p/WgB0NlJHjQ46RJdi/HTu0lfpXX7oVL5///R0c5Xz0zsLtuJ7Frct+S09 languages/routeros.min.js
sha384-06tnC2tnDaWQQoAJqgih9CeWpNxAcFLqd6g8UxiaHGWMlLPRd4YwuZwuhPqYizRu languages/rsl.min.js
sha384-Ky5gnCdmCwZ3CDDVl7YFNMFlJBQB8UI7sJBx8Khm16mGP2lYMHtlvFW+60dDHvsR languages/ruby.min.js
sha384-TP/IEEWj45fTmegAFzz+Wt7DCU3njRgoz4h4y3dnJWNQ5N+Q2Di9yggzpy3r7D9v languages/ruleslanguage.min.js
sha384-uI70yO+YYYXxO0GQawrwFNlkQe7AGK+DD+g/4CUuo5ulF+FAsLEPpYTAFh4ZYRFO languages/rust.min.js
sha384-nvqzKLlF/iauZMV8xJLoNkwWhii0JEs5mTXQfOW1Uo2DtO+53iiyCluVAEgVRYqt languages/sas.min.js
sha384-eCVtany2DIrbCFi0z7fnkFphSdrsC4Fh93QTeK8EOB39+t18cUsNnwA4bEZy15iC languages/scala.min.js
sha384-VYpz6vTIerUSVWCNTESsjiuUodvvNnR+DUsIvdPPwVo1lLSiaZzNvEgkP4+WkDiq languages/scheme.min.js
sha384-rYCYjzpai5TH+feq74Z4rz0cVb6YJeBqgx9DMjufP0y+o57Qoi3wpcyn1ix7kmwB languages/scilab.min.js
sha384-TDiEpjMHcQCk2X/1Zot3isWvT4LNmp+fVa56ZnaowSTH7HuhFQt7geBsQd5zKn0H languages/smali.min.js
sha384-rmLIfCFcn8mygH6Y86r4PrVfYLc4hYBWyra3IyUs1O8X2KuLJJ0pUhiRcyL3Fa3N languages/shell.min.js
sha384-qjIiLEWMpK0dlsA/C2Iqlf0bV2FX3wh54RrmICGhe/eM8Anrs2UhX6CfzXMSD4My languages/smalltalk.min.js
sha384-1d4j+FthwWV4IAgceak3vMVdVRsG/2S1Ds9S3qT++JBiALrPwHn9/sFzRhp1GdLh languages/sml.min.js
sha384-dhQiz2V8l03lAVnShG/6660Kt1b4khPl6W3w7qjqiujgpYVE5Y5zE9AYl5O8WinE languages/sql.min.js
sha384-QhUwKyrMx2dyWZnnNOAjana79Fz3YypgXNNRV7Apt2rkMWkHAPO5Ajl2rRSvG/As languages/stan.min.js
sha384-tq5TPMSeXOmDqfpsnCj5zfWIBiBG1WEWKwk49sI4kqIUX6/uHpl3vIcEHHHwJ2vo languages/step21.min.js
sha384-4Yz4/kCTBAU6bZDmOtyzUOiwk9Fi6157ynfK+6D2uw/XAfymMpIqnVPwJrz2lf4z languages/subunit.min.js
sha384-jRdXRoItXe0oGQRjfAtFLpOV0qR8bzbdt98n0uk5Cgne27tfCUQHcstiF0DbJyXb languages/taggerscript.min.js
sha384-rCGpLJNtJ1lPxwl6OF4E6RIPvTLQueLUz/BZ3gWkn+JbKkdlanHRVErFWzEuymVF languages/tcl.min.js
sha384-CXDbuRkzumQlu3rnR+lHSDDZEdwS60b6zn0KpKA1nA4QPiH7Cs7zNB6qFkeR60T7 languages/tap.min.js
sha384-0wM19FNMQva7zojgVEwdElYK3tAikvJHer633eytubLBFSw8sSR4NdIpBdYU+dEP languages/thrift.min.js
sha384-qPorU7b6h32qCyvjWDNeKeY2mDCmtIWTvn5khS8H8jtOCGuVZQ+kS8rF2PhcHZE2 languages/tp.min.js
sha384-hyDf5YrUYueVuL/IJLoe6rwWdAdBwNztA8VwqFwmeJQfrhOvHD1hDv/OmQ9Ny0s4 languages/twig.min.js
sha384-Gd8E0Vl/LZoar6K0YjXZ3sRnmK/ebKtycnGu4BoUl/Y0nHdD9L1Mo4ny3OmJDxs/ languages/vala.min.js
sha384-7LLc95xpdfey5QDa/rhRpu9D8ZbkgwhtO5yPv6YEWPUGYIglQoA82UXPEZdC/2PK languages/vbnet.min.js
sha384-4n3SYq9Xv8UnOyK4mmEcw5B118Enx6LOW7pYmvgfhuvFJZ2xg5FP2GAiUwXTzyoA languages/vbscript-html.min.js
sha384-dWOVKEmYjnVCdRPxL120pqC7sABlvfD3zovlEnL4BBCq+6amIYSMrZgFeRG4grka languages/vbscript.min.js
sha384-5nYOjQL2syDQdJpXuoC2BIu3rvMLr4S2yS2MQd4gVzujF5UfgUDekFJoiHS+Fr2q languages/verilog.min.js
sha384-EiZ76VOJB5gVIWHzvXCEI8G1gVlQqYBV4bg9fhSOrekDVRUSkfXDhfFtNTBWOc6L languages/vhdl.min.js
sha384-2zXflB/t+Y260Q94d8FO4/v5MRbdKpk6d/9jQjBCoalFSnWnpulSblUWhVcG59k1 languages/vim.min.js
sha384-UmHrDINJ1KDISH15risB/jh2kKPIwZhmoOVgnsgxaknRM4TxjLuXoLFO9V40Gue3 languages/wasm.min.js
sha384-02uDxgU79M7rBNn3HN409wNYv6h9c/QkSodIJfYL4hMLdMJwo+HWp1jFv4p8H5pr languages/wren.min.js
sha384-PJZUzMPejNH0h/xIFxYw03I16xIOWvaH3/9lEGu/Pd8aBcLvWOQpGPGUFch0Err/ languages/xl.min.js
sha384-fife22HSGlB4iCcHRErcD56eJGW22SZiNvevxyBJ0oXuaksqSNKxHqF2z7XoBN1O languages/xquery.min.js
sha384-2EmiKMTdWnSvNY/+TcIQUBQE+dPVLLmG4Z4A/w4g5lnfLzjZkPnybnw/4dM4amaK languages/xml.min.js
sha384-/YBEEWRCQdfuNHlw6ouCO7rbR82YMhyUJMafjQCG1YFZ3jTNn/hX+cl4X3B23NAj languages/yaml.min.js
sha384-lRs5flb4ACMUEE2961OtexFarMkt3uLqkqQRYATqAtAzZ+xYN3fa6nPliY59ECKY languages/zephir.min.js
sha384-zSyd1DLjAdrAxrJSIprRqsPjEefi5ue8MKqm0KLEia+Kv3+X4gji3NHoRLNjOMY7 languages/powershell.min.js
sha384-Pb3kvj8Xye8Rq9z+Pgt/QJ0dsUBi/b7zeoGvcjDdo3YepDLhqyy4Tcmp9a6S7Rch languages/gauss.min.js
sha384-Q6Gs2/I2F1Yv0e2BmHiLIqJROgMsBMoZADhTJhsbouU6vaCmXMTcWTUfPCa8oJTL languages/mel.min.js
sha384-dj9CfsE0quHXlzgDkwlbPYjsbHUHWrbylMHdnhMgSIm5AgaDsOvw+oukHpryFeUV languages/dust.min.js
sha384-q66uQ3YHrnOtn9aFFzVDjq58g6tA8Kt1yUZvw3WO8UBGHDnO8589qpsncMY+bpEf languages/dts.min.js
sha384-zLVeBCK8rosI2LCUAMLxqrsTfvmIGGsee263RsdJ4FAzQDGFbb4k1AAORJO5JtNB languages/pgsql.min.js
sha384-ykc2c2KIAd8nfD4uM3abws087OPhNWrzMikHylsq3VhTiI4f2T6QfDabMpcYOooT languages/stata.min.js
sha384-JF4QlS2lB4EX7dFwNWl4l1dNKctHv6Otm+yVqJxaEBgL4q7l2u8iCOrnX/BJIyVE languages/x86asm.min.js
sha384-jNieX7pd9SDJOTbxxXAMaSu8PthgP6s2iXmMA1bbS9sXcjAdloAgq0kFR+D5nTm1 languages/maxima.min.js
sha384-PVdNL6sHdVlEA4Qk6j+6IuZm1dIAzTgP0ijWunaV4Wg/rKzVWe8DiDA+PgGvTpFR languages/1c.min.js
sha384-8uRMmmbKVsXBE9BCilYI0E1uohahwlSy/gO9XWqKhYnjf8kSa26ZmXf24HgSuk2U es/languages/abnf.min.js
sha384-/odl4DYodanQe71VERfM/h2g527IgpehcYXprtTXGzhInS0wi6CLlcancccrKlC7 es/languages/accesslog.min.js
sha384-GcZpEPrtu7Ql7ou2bts7F+lMek8pKAeKnC6rLmNajk3LmLrpa/ZbWv2E1c+qLtTR es/languages/ada.min.js
sha384-6scWrAnxMt+1KiYRFQ89wTsfipaDDnIZ9UMP3CQgKz5WxVshuz3AjJ+vc3e0KLes es/languages/actionscript.min.js
sha384-kjDQ7ELX4YOiv5z2jhJey0gGa7NgSACUMhudkrEy2Pj3D1/G2QNfYmauJPZm/PbL es/languages/angelscript.min.js
sha384-wQh7zC5qOhJO/OD1sPngP8ZE+4BT9yeKslvc9ENceWvn4v5oUGqmHUn00Z3AZygc es/languages/apache.min.js
sha384-dZjBhHd0eqxRUU00QSb3iG2V7RUd5UKuAXlPlsKem55xWpzco8LfJ+FZNGPFAjOJ es/languages/applescript.min.js
sha384-Ihlzp06+xrlGH16wgesProojwhdjvKNntoIStbUVR/Jm53fpVZoEcTiHciBdxRB0 es/languages/arcade.min.js
sha384-c+MoAZmVeo0r19SZ6Sth6Yo0O+7USBkqBY1NTDiuVHzz5bGfFib2fNtV4WZje3o9 es/languages/armasm.min.js
sha384-OzqNxTvrYTg9j4E1fonwx0UnfbYOQYfEnDnm7wSp/1tdo2b+Hb3SoWX285G9GcNZ es/languages/asciidoc.min.js
sha384-gOrmaNUmIp3tTdFvph1w7D3y74lPrKDk/4nqP/68tcV7gn0Hs7D+gW0YUBz7+4Kc es/languages/autohotkey.min.js
sha384-9d9sBNU9vvK9kggXI7mZP5+C9SaJGMS2Tit9LneV5ROSJhbmPuw6OdEY9cejioiw es/languages/aspectj.min.js
sha384-57NnW18adxHVlQF+qGOQSO+HJmpc1efCs9N7pdYmpyjWpWqo2WeQ4ZMzkTJJyFPY es/languages/avrasm.min.js
sha384-VKOxu4SYos1mLCE9WhOUjnK+eo3YgE94AsqL2ICghmUGgu+drZq6XQmSzG8AaI/H es/languages/autoit.min.js
sha384-Gk+B8WbvMJF700rIaezVRW28qmsz9jnVUhjlO3M16kEoWLcCqCLC/lQDeTnMeNkg es/languages/awk.min.js
sha384-GWWZE9Sz1pgD3knoNFWWRblxvJglVt2D+Wa2nd5YaRY1IcGOa6kVRTgZ/qAPgGAK es/languages/axapta.min.js
sha384-Hn7VZp8ODG+3AvcOhCC3jcRdejLbdUObZ1CGhH6hXgNaNZ2XqkDVwkTDJmh//jC5 es/languages/bash.min.js
sha384-uhbvgD4HxY2QoKzLw550taAJxvbkNTNVUshcFkD0hqQhd979Q0q2RYPwt0iUFmB1 es/languages/basic.min.js
sha384-1l3tL8qiTWdZv97u3jzjsf46i1g9wjJbVfxW1Hhm+XVMNVI0v66jNI7/awGXWz+B es/languages/bnf.min.js
sha384-Gf2hRCvE1PNEJhmRpE6bABXGyFE+BjtBeKF+axus0H/S7HbXvtqqSblPArjuJFYm es/languages/brainfuck.min.js
sha384-jrJLUMv7/y9m9tnZszOEelV64nKnhXUiB6BBg1qxL4yee5FgfIJzxdfBEXoYvL3V es/languages/cal.min.js
sha384-IeJGtnYfogFR6t/R3nATIt9z8vb/1y+Wf+9nyacFi+Mz1cPEkD93PMMyijquSgrN es/languages/c.min.js
sha384-sF3yRuYD9NAIhybLLoU6nuwXQALwkZM1iK/jlNhqb2FqXorhFmZL4E7nXU7dlExt es/languages/capnproto.min.js
sha384-hdLOg4+RnRSUMf5t/ELUBDG7SbEyeLGKIXpsVLyYiXboe0c8sEhuYl7qbePV47em es/languages/ceylon.min.js
sha384-6Z8nAJNsvcJI2srA9Z85H/pIQOPiCdd1yzi2SsRsWAoljxxEieaEQfe/i1al0+w5 es/languages/clean.min.js
sha384-5ZG8BYAyFACexQo2R9zUx/Ko87W03VNv86LBj2KBufd/4IoHTcgRqA1bnmQEbPfA es/languages/clojure.min.js
sha384-98/Q84iAQW74nqkdM5Nbq4pkSOJXb1ToLJ1v4ZrmWfJSXdnDWhrujj218brZz8f1 es/languages/clojure-repl.min.js
sha384-HpSthsBtUGU26AV9F4CPajlunHL7QRoKxTIXCTlU60s6gU83qAPuk5Fh1OdPff8z es/languages/cmake.min.js
sha384-p2rlXyFKGGkW8nzfBoKIgKG8OpwV75wTETF9Kf0mLzEvkbcBiiocEwol/RAYeFqa es/languages/coq.min.js
sha384-G3DBc2ivZTINf7ADkT3dyBRU1HFzAjKS6daWZ9LMr5Qehk+yDjbVPwKQ1/LybGkz es/languages/cos.min.js
sha384-v3kzCJbvHFwjN18mnXRNm9ObVLWSWY/wQEv+GKrVAUcjo2Ry3GDRV9g3y1SZHHzA es/languages/cpp.min.js
sha384-sF647u/WnfDFSCax9GVVa+x9VYmmT0/a01oyP0Pt2o+yiIxM1qTCbj3fhVBBUes/ es/languages/crmsh.min.js
sha384-YBAIFXKZ2JFZIKswg+hPOVGtvTtMC2i3o9PDiuDBHV5KF1Lo/Hpprh4+86vqkJM3 es/languages/crystal.min.js
sha384-AkTHilUMDRaoDUaktEXISfUcguuqPpIkFwv13nGeiXO4SxeOnaJQSHmjKPmp59l6 es/languages/csp.min.js
sha384-Gnav0V7RCWOnIbzsdYzxxfSRx0MaG8NHnQgbw+IVvJcm24dh2iVQPysyL91RRPw7 es/languages/csharp.min.js
sha384-xpZryes6kayLNqaJTtbq0RrsnDajBO9D2h44ILLzw9IvSV1Po6OD5pMX2BGqbxwr es/languages/d.min.js
sha384-JVVdh5s1Yk3mFG8uxizmlj4eKWsWbzz5zpyS/z3Fdiryc6+z28xVDucMIyBrRzwv es/languages/dart.min.js
sha384-J3NwByAbw1VUshDT0RwcGC77lKaemr8xoFllEFYYaTvNpDu9w65xTRF6iLtuMRCp es/languages/delphi.min.js
sha384-dgjG/LEJXUoNMFkJM4QtT5qyrXeePuL7CG0mZCaCqoFPtmuXA6zALhnkRMvpx17c es/languages/diff.min.js
sha384-nCtR1OPcA3iCufES3ibMhn/l8I3PtjIDUKy0HM5Tzk5C837mmT5V5dEmhirqk+v9 es/languages/django.min.js
sha384-EUs/4yle2oD1CSHzh/LYfe4ZW1KR0ku+ZpY2rElP1gQ1JEPsajxfanbNv6fi2XfM es/languages/dns.min.js
sha384-2H2H+yTN0uYRdqixDEyuth68y1048u1afDYFqWCNC6MHoQnmuDhlmMPgPHaAt6fO es/languages/dos.min.js
sha384-mjjiPiHsRUcaphQS2szUpMVZRIdrlRwDLqi846q9Z7RoUpk2CAvF4xQnHfmT5Prh es/languages/dockerfile.min.js
sha384-xTQHPJexFMpnR8X4c0+XWdwBprs7BbqO2w3HMY+FnvMiN0YkWyA8xYDAd5FjAfQv es/languages/ebnf.min.js
sha384-VjoiNd17urGVtuv3nt4Uwyxyu948qwzM0m67yEPwAfs4fIhVFqZkXyNzjz6GiFjA es/languages/elixir.min.js
sha384-iFjwh06MfYaO1oaGgj3roEFtY3Zmfpa2rMzJt4Su9VRVkouwEv2xfnYsgj/P+P0u es/languages/elm.min.js
sha384-vMRhHWL4uW49Igp9jx/YXDfoVLNPplDkfj71BM3Xo+ZHYDR/ivgVBbNIvj2OxPT0 es/languages/dsconfig.min.js
sha384-3doFn6lSyM1aHeKQ4rCnrl+ZxvFoz4B9uPrdFGWzBDPUpMvBzzEyYw2iUXLlz497 es/languages/erb.min.js
sha384-nrQ0Ofczn5z5KBh/9Z4fiktKj8r7cBbHMzSfsUKl6OwqgfhtzIAtoVhAeJn2Mp87 es/languages/erlang.min.js
sha384-TupldVYLrWPK8fb8HyiYYdjof1TqcKdjWkO0AugnYv5hjiz1g/Lxk4yB59VNjTWH es/languages/erlang-repl.min.js
sha384-U4s4PLjUZ2Yz1KFyU51Rwu2J0vvBFK1Hkalwgxopb8YdfMspwlbaSJRBTDXN3G71 es/languages/excel.min.js
sha384-LGf+wbYcnDbHY22QmWi8Y0mLCRDXfScWhaQ9WKkqOllhccro/Qtsq+AeKerqEfXQ es/languages/fix.min.js
sha384-SSl/nZNBIz+drLFblh36SsiegNO81xJ/f43SjyQlWar0/4TXty/grE19WCUo+P54 es/languages/fortran.min.js
sha384-ya23twFQx1t+ztnba1Pax6f9SLZ7tjZATAUrkgzbtECednp7vpGmTZ25IcbV23OL es/languages/flix.min.js
sha384-P+dG13vQ7k+XnamN/2BhVPpliXfspYkh7YyThc05LUklC+LTy3Xa0yb16pTrK7CC es/languages/gams.min.js
sha384-6ISrfPhM7BphswdkI8ZBoUjGVRi3TjEZ+MOe1N+a3OuJzkqRaxikblsyF54KqhbT es/languages/gherkin.min.js
sha384-+q32KxrKrGh4p1I9G1eYgR5PcktE9FegMxfQaens6E3kRoAYb+iBqbE+W7xgmrAq es/languages/gcode.min.js
sha384-fP0jd+BqFjGNTsCJsxtX//CP+GK/8lQR5k1z/XCGNMFUvTVK/ugv+0podd5Zknmy es/languages/glsl.min.js
sha384-sIQZzg+gv8xvK7bWqbmMv3GSgpmVzDs54B/DIVdg54mQfYHnIiS7x8Y0X2ZBMwY8 es/languages/go.min.js
sha384-1PXMmMCRzzhth5n5VDXBLBKq/O3FJuou9f93N7vAjI/ic3f+xsEszEGt4jiWKwhg es/languages/gradle.min.js
sha384-x7oeu5/3DUBm8kVQsZJXN/N4IF0y7Egp2gSQp0geGxGoEOrefBCI/Z3aKVBQQW35 es/languages/golo.min.js
sha384-fUXDi+zXpJv8LBDIRcD76woExv0Y/Y3NAdnQ8Qzzcrw8gNTPTap6GVGSiqMUUxyL es/languages/graphql.min.js
sha384-By8DqnM4OOsHckVcPg8BxwHoZQjwvS/5cH/ti9kDXWx9oAa9wG1wOtxZiCRserRE es/languages/haml.min.js
sha384-yMRx/RLoNtqcibpVW3wZ/6rqyJhfl5Sdmmbg5AIFUii+duzaX6f7yUhd9lzNIk9h es/languages/groovy.min.js
sha384-xWSPcJED4K8B2GXMmMcvoBqE1MOh0Lbf0+5la4JH90qAYGZhPPfQC4xFvv5T/7ia es/languages/handlebars.min.js
sha384-V4YzkRIkZbHWwIUEW9SrhadBe2kymJnSyKfYFg0kRwPQQ7c2AznRxA4pWU8IRK8H es/languages/haskell.min.js
sha384-Lvs/1OqjMlM7hy+1PWjjGkbIs/kQMHuyx7dBN3RY9pk6eZSk1Po2CsxcRn+NgiBN es/languages/hsp.min.js
sha384-JA2nUk8BOvLQ3m72CYlONCFxDNuwMc2MZ5m3HPpkuXCuaQdYnQbnY4WZf9qFoseH es/languages/haxe.min.js
sha384-ji7mePZNMaDlPkZpH2cMUq/6LB1En1ZQ6N2rdZ4UpsckQYyR5IuvpPqR/4TgNVVk es/languages/http.min.js
sha384-FkN7j+TFgSDQMlB2ydk7+CkICEZkcdFyEQnUWbG763IcB1YAalLFUNYn1BKEuPfM es/languages/hy.min.js
sha384-qC3eMjnfawOKi5+PDIiZhfSSqwfoToFQmMa1PleDeRWUfq6TXFqMuEuB+tBtQhaZ es/languages/inform7.min.js
sha384-++8g/atY5qo3CruPYs85v+uS5YgOaPlNhDY3rRd+4e359OJk9jH6Qj4Ux6QRnC2s es/languages/ini.min.js
sha384-xeSTxDunv0FPly1ZqmwAscrYliloE/y+1bMF4jN2IqBMcfJv//oymn1wpNz76Mej es/languages/irpf90.min.js
sha384-JOtbQ0u71NrYqdHbASGs2a9HSbKr1mHdm04G2YlfKhuJLND0dSbw9OvoF6sObQie es/languages/jboss-cli.min.js
sha384-k6IcPCIIyRIJvOAR08bo4Vgt3mfiQ7eizMo3So+Uny/eRAjtEjncblB04ytT1a9I es/languages/julia-repl.min.js
sha384-O/mEB4j1g1GjvwNlHEUCHL4E+nwj62sjkwaGvvil9y/iJ0rgRuMhoGj3Leg5jo3e es/languages/json.min.js
sha384-Gl2f8TAM91q17xxtl7/gW1js1pg1KM0TP66eJAhj881TY9M+fVB2DceNIjVKHwVb es/languages/julia.min.js
sha384-XOi273vWk6pEwAF2b8eNJmKzoujqhHCy980Hk9GroEUvu4DxX5H721MaJ5TQwS+A es/languages/latex.min.js
sha384-sOveKXukA9LvrWj7yzbSrdFSpNLtECWHm0Ag1A3QWfxZTEJw9B2A+zvJXhvEkcBV es/languages/lasso.min.js
sha384-LS2OwMlf4fr9bfMt8x/nl6zqIZOuXA3I00U2kvQxaaKM/bxm3gngYT4u5fZXHj2W es/languages/ldif.min.js
sha384-X6vnD+W3NWcGaAu7nkFfkbNtaZX86efZ8mQEw3d5/iOQSbvdfykPC40ncsriEyt5 es/languages/leaf.min.js
sha384-uLowsobPQ1v90D0U96x7tjeiyVAZsqPrYCsAxac73Orjd13GyOtewyJppnYJXHfL es/languages/lisp.min.js
sha384-GvE4ranhmhNe2T7XpGdtOPLjRt/CUSiRv9zLhG8RsLNem3EBbw8pRzsNHhiMaA+q es/languages/livecodeserver.min.js
sha384-Y17ZFVgNa/vuOQIF5lnLdnLv3o93PssVZvPtJ4yRDqDJK7CrbUsLmX0uSLGV4VaG es/languages/llvm.min.js
sha384-4DWdwWXuwWLNCSSColS3VjM2Vfwwhsm0u9cIJ209GWKOsXj3mh9904UWlRp4DYJc es/languages/lsl.min.js
sha384-JafohGLpO10BQ7Xc49ryvd1XRkG28WhQzK+7jynyLbEpQ4nzUZMi33mX94aMrIXT es/languages/lua.min.js
sha384-WQGMziNc1oRlo1epZfythS9j3E+AMeyO7/vMQaGIQ+8uVugPPJOAtLZ6DWj0Z6at es/languages/makefile.min.js
sha384-ncJsuwSb/UQCzHRiI3yT7mGvk8qr6qb5rWtlQSibKUCXPCNY72V5FIEtp8NCTFNv es/languages/markdown.min.js
sha384-YHA536QRbVEcl5byA0MmbEQZDaCnF5R7XPjaqO0Nb11uz9bfDgJ818auZ2tqQR64 es/languages/matlab.min.js
sha384-eS7k5vV7RtYLOR+Jf8OfHapuj0zvnUDL2CaqmrDSLK5zLAcup5wJ517EHcT/5FhL es/languages/mercury.min.js
sha384-FR1coRt7DX2F83PIDdiu4usspsCUYjvY+R1WnJQlFFpCxBYZotuvhjnvUiMI9Pgm es/languages/mipsasm.min.js
sha384-Fdp6IvKTP5wpCeT4DrBmufyWbGOThqJjHcDCKC1nfdHRbQoEAZUUOkGk/RulCioz es/languages/mizar.min.js
sha384-S+dU6mJTOioFo8+4N/TkZgX19NmOb7qFP8oX1VTbPlH/4IOwPW8uAEOq2z/JRZ9d es/languages/monkey.min.js
sha384-Etpoe0B0nCC6A98D70uzskNgLLEjhXTYcNBr/cmeJRhmIsGmuP7cFjGssygVqH4P es/languages/mojolicious.min.js
sha384-Fs2qUCUiMyTXReAP3laGyXEWjLfuQ9gXYnnAvwBljJ+x/jCmhJTBnJ0uIwEZ64NS es/languages/moonscript.min.js
sha384-uYn0/uTJ2qBisdOh8s2QeaK5vilV8OiZMcMwESv6LnLczD6NBDY1CCvj4jlDcSDN es/languages/nestedtext.min.js
sha384-gaX1v9ucWuTeBJeL+2etADgiuvq2L/UN2UaFsj+egV6t8VODuHciSXpj39W5Py78 es/languages/nginx.min.js
sha384-92FmtYpZxIfYUF86w/qlOE/GAD0ugRaNAUzOzRzXw3RnHSpw3fyvsoKMhjBOlHGR es/languages/n1ql.min.js
sha384-+1Eckh7YPs+uh8iU9JfIJiP1lGqvCxYDifHT0/7WLWrlAntql482dDMDp8g6/5ZA es/languages/nim.min.js
sha384-zkxvxCdPZNaTWlmgTr/70B6Kt3ABvx2aNoz+TUW6Mn4XAciJAxj/Fv76JPEkkygH es/languages/node-repl.min.js
sha384-l8jvEwoud5tLKbZLzmGcGbR1phCQmOGzIn/J6Gyd11PRFLftKtea/ot/K7+pEOx5 es/languages/nix.min.js
sha384-P2VkdDR1uIW/M5IEha3LugA7J6X9FFwojRqR+RnLLqoTR9kryJYYjZbLjBjeRwt4 es/languages/objectivec.min.js
sha384-UEcd6rE7xeyUYGkqTwMcz2UNl5fhCStR5aQ90Qn8TpV6qD4mlzQy1DIvRFa5VGAZ es/languages/ocaml.min.js
sha384-cS7CfrCJ/AxDr03uaeoIGx+WADs3hwQZOYXll+iYzxKx/XG+PgbDEZmRKd/BwBVZ es/languages/openscad.min.js
sha384-CE6qbYCaaqlCLQ8cNIAhEH1o+GMxsUEj1MSMEzOSRJC3mVYZ0gSkiuTN/mE6jU9H es/languages/oxygene.min.js
sha384-fhODhTCeWY0ZaHWZvSxqOY0vfL++/vRDP001fEbwOJGhP1W4L6+YrIR3HCUmR5i+ es/languages/parser3.min.js
sha384-kTNfTuLTQKLEbS2+BNhgJniEohwd2MB8OsZG4KA2VIaSdR1IkEAxUK8Ml0qMfQVz es/languages/perl.min.js
sha384-PmhIL4EcESULo/nWfBiXD5nimpwuDlOZANrstuE36JPunBxnCfcIztRjyAY81aie es/languages/pf.min.js
sha384-W7axV/YAFnmN3tHjuJspp7kY3A27GC9qH8dwEH+J/nTkJuemUKJ2u21nCIF2Wwh+ es/languages/php-template.min.js
sha384-y1pbATwBa3iCiSAFMha8uFWhepCEFxrVDDRq/8LacbAF/Fo8ZqP19xP9kAGd0DYU es/languages/php.min.js
sha384-uKo3I52xhGo5zmx9L0xFQUDyI01EtCoJXSHzX/H1Nn5gkWz14EfehKuXp5Gcz3r0 es/languages/plaintext.min.js
sha384-19skYim80M9l25dfvaih1arZbC3AJ5WdcsMWBLiXErALbfvHqepo6YQZkZ9i+ScV es/languages/pony.min.js
sha384-Oy3qpg6kjTitcXlgEwLrlSR4oE8jU61V98gBOAyLQsX27hRQ2oBGwmXFkXS9c9Lq es/languages/processing.min.js
sha384-4ZzI8BCkJ2mOPa3tptTYwkkeb1HwA8dU4904nVBATvZ4unOZU2aFidYqtkBlSGog es/languages/profile.min.js
sha384-LehemM6TtA5pGHJ53rUU2+4rUiYkSnRPSx/7NblLPSiASRlq2MNpAKh5G6Lup/vP es/languages/prolog.min.js
sha384-If+gklSa+QGkrQa+Gx/Denj80uIUTquqYMxSV3lrOntKiolEFI1QWSRWcYb2uOFr es/languages/properties.min.js
sha384-ptmPRpV5MY1vXoHBtwVkZvLEe428crXBQrQXFHUmBAFXQ7lF2QNOLrjrOIKiM70H es/languages/puppet.min.js
sha384-d5DQRO2eJ4QPx3jpUDyAAKhYKtFzRR1Mqw3uCbm98SmqM6S7jVQsPxnw3cyzLlfO es/languages/protobuf.min.js
sha384-cVr2OZw9BAyl+kzPBDuXsY7co/fAn5JkHZLj0yhGqtQy06iW5xU14dV6UMv19ArM es/languages/purebasic.min.js
sha384-nQOoZNLyT/U1rSF+ee8I1shbuKvUs4PewaYyv3iiDEanBJjs7M5sHjXSC46lGBCi es/languages/python-repl.min.js
sha384-Ok+vqa0XFaVnoT4a+lVzhMwPEbCJNQToVWIZscwyEq0ysb8DK+qTOAl1LGa8nbCJ es/languages/q.min.js
sha384-1jMvGIi5xaN9qvXV3N9+8J81LHj2jpeLZy3AK32K8zXk362w0ixuXMI78e4vJEJu es/languages/qml.min.js
sha384-riZZZUS/9qyDeO6zf2Q+qFsShQ2nz8MlQ5ExbfMDfkFxXzB76u/ui6JXOdOmUrUI es/languages/r.min.js
sha384-djtC3nMKRlAqU2sGkWWcO2c37xrYq5KMZBFRcmyyCJu8sLTKj7WOZpdQc82KjN/f es/languages/reasonml.min.js
sha384-V6P7vFSITNC5FrWWC9ysIhJrHnh0FpgQtTuoR900s1ot1JwIefVz4EeNVtVZ+Feq es/languages/rib.min.js
sha384-w/08W/LXBVpGfOFchDrflGtS0vSEs0ocek8ChBu+DVVUC2L7R4kw5dAxznc0j9v4 es/languages/roboconf.min.js
sha384-Hbk+/NnJPxU/GKVqlzf1qSQ3IUdfPhrBuD0RkDZ7OuQIEemA3L8oOZHeYEEX74eK es/languages/routeros.min.js
sha384-N/xJyq6RXmpF650QjqpXYAjbvfAmvu7cgrcsyRntmN8ThE0gQo9Bs2/qH9u+1H+H es/languages/rsl.min.js
sha384-cayYAGBgQgkP+LrkknLyr5/bOtcUDpT5x8zE7ghksk3udJTcHqaYbFxmWTcn7C7m es/languages/python.min.js
sha384-7VO/UZL11zr/hit7ylrgh1RNFHeqJwwEb3BQ1GHS4wEldra7eN1HbcYc5/O91MBd es/languages/ruby.min.js
sha384-5aPZA6SrpkUZ0gcI7G88cbiaRerv/N0lqPknwl5MBM5fg4L5kDCkibTV85TkrSSA es/languages/ruleslanguage.min.js
sha384-EJmm61BjtOLplFPTU06NkZJWkMPEneFfcGlLpcEwH6lj7lL6a/aaOmdpRQylY3sD es/languages/rust.min.js
sha384-J+vEko6ltEnr3NWCDS1WAEj9Nrb07yVQ0+9V1EC6lCutxXc2kfnA/vugKYd1Hfc7 es/languages/sas.min.js
sha384-Tjd+uK0PvQjpMagoJfzXSdQQRfqmb+V+5AWkVfoylVVRWBID06MrArlTxQiwL3sj es/languages/scala.min.js
sha384-/hxUm1dB+zqCON9deVEkf1jEq7iDEVeZ8mkkt6ly9QLMxsFgNhe/Xar8u5p3sDn3 es/languages/scheme.min.js
sha384-K7+Uw2e/eOpzfJUeao7lbNq5b6eY9knrM2kB+bmCGKTfw2OV/KalIvdWHH4QcdYl es/languages/scilab.min.js
sha384-YbAX0iV5nA237iZo9HGyY1LP1OUsFh5PPJJ5nO3ZmdYq6Xl2XNdZncKNC+TraBTg es/languages/smali.min.js
sha384-W+56b6SI/gvNiN85ZdzhyWxl72RMCfiw5fjAG+f9FHXTQZpoEQr2IAOK6I0bKMRO es/languages/shell.min.js
sha384-ux/UdIxHsErysOfFRbPfscgcmuEv82bGnlv/vkkDpLym8ug7fw5idjQV4RPQazL6 es/languages/smalltalk.min.js
sha384-4elQAc1lK1SDYfv1hS9daMJQHA47ez7v8ZtrELG70tPsXUS6OQ5/aFqYKKBhtpit languages/sqf.min.js
sha384-F5DisnajRaZEnnDRZgrIgk7Y3LVK/aGssCrJhGC8kyblscUkN/tIJmDNqq6iH50T es/languages/sml.min.js
sha384-NGIDPAxt3NXQRrzj/81/sBBuj9WacvNqpV3RbYJJ8w9W8s7rXHJP8LJH/9bLllvQ es/languages/sql.min.js
sha384-+kd06u6XSG2BFt2a4FniTPH3tuv8Lybj/y4mlpFYoIU6emkbPa2/2u2bxOAYNmRw es/languages/stan.min.js
sha384-+RERi4bQy4WEkk8A0Q5BpdjmNZYIxduoAXWD3JO32VqEii+spNLlCZwNhmrOQfdI es/languages/step21.min.js
sha384-i98cQWSHB1NLGWxHO07rppJ4BuKVaTi9xHdT8GJCLhu3SXbVLq+ho5kMca35IovN es/languages/subunit.min.js
sha384-rmkw56hh6VV/IMcy2C0LrQi8PIAM32qFysq0X2wBopCpAmxQ0qJvST/z6RoT0gyO es/languages/taggerscript.min.js
sha384-wnOBXEqhZPBetsfOAfeARLyhz7ku2Ndn1RAXf7Bbi82Ip5fUIEDR44N5/OR9iJcY es/languages/tcl.min.js
sha384-/PaGMVo0tnQ9UXhchk/G44aWNMXGQJTW5p5nrGhw7qkoIcI3B883whORUzSzoA2P es/languages/tap.min.js
sha384-g7K9v3EuPqAkKqEeF4XVlsY/Fd0FE9UaY/yMqQsVhERsYoVTVAACjk536Xbie4Yy es/languages/thrift.min.js
sha384-CLTrvVfUiiBoxbXvgoNnd6rO+Qvp6gy1dM6EIGowvWWjUjFsAZkUraa+gKoUaOu2 es/languages/tp.min.js
sha384-j7Tu2G2yuzR/0Fy5dreAJrYt37IHAU/w+JlCS4fS4VL15RbwxG0n7dSU0zdvv0F/ es/languages/twig.min.js
sha384-3dxNOvI0NTd314v+xWERWamjXNwAqNK9wF0F8bwmHavSS9r9UMEHLIIJeiUNJ4N6 es/languages/vala.min.js
sha384-kzr3j2RxtnOvYkKQn63DaBVALHGBnnOF0CG0BCeT17gxOCzFS+/zfD3f8e1Anhrw es/languages/vbnet.min.js
sha384-7PXeOXHL0NElYUFcGs58Yzz9+rmV3+boOZ/1pm8445spasvgr65xa8FcFYfNXUzM es/languages/vbscript-html.min.js
sha384-42ZUIXSGkUBa73482dZXTl/jX1kVM5gPLKM4oc6cm1EExHyIlhjMl24jYTKmDJnX es/languages/vbscript.min.js
sha384-jmwrdZIhSwmhXERwZzhTfYqIdKCB7FBDj3yBgRZaGaElCY3qqQZM4uiVdOO3d5vy es/languages/verilog.min.js
sha384-w0940Ux9GuK/UZ/kxk1En3ObPakcx9Droxb3G6n6PHdHIchBd6D7RcFUihebi5ue es/languages/vhdl.min.js
sha384-jPcUrHvGDet+GHJnxR8HAMzj8fInApB2fFd2r2Oa4i1jPXeVXjAb5ExCKr2LVgBz es/languages/vim.min.js
sha384-TZfNN2QlgAc64OEWFIBWLXkCPWI6m68LODxw4/rLGZyQtNNs8g2LAK7yz9AOSj+5 es/languages/wasm.min.js
sha384-LZzSpINoSbzwOoGUrtUOdX6KuGCqrT762h4d+pgQJoEG2j3+4hWjk00iXTSElvoZ es/languages/wren.min.js
sha384-1MN2MkAL6NrAx/oj/+iob3bQ9iizOIe7WS6WADQwnpvfn/VXVzIF6dO6y/PbndjA es/languages/xl.min.js
sha384-WhUXsHZ7yPZwLssyTVY/rg6g2wLy/m745X60ai4yUPMDqQ9msHBTkl4q7sbO2koE es/languages/xquery.min.js
sha384-5CNudUe0z3b0cMqyTgYNBlSfB0BQ2zC9AWHFJ6pSqs00lsW0sL655SkKNF/Bahdn es/languages/xml.min.js
sha384-uhMTZGiWcweYoPcvbxKBh3YYXots5DDJt5GNPYUydQuAhp4/WPUW18kK7TL9DSI5 es/languages/yaml.min.js
sha384-7iF62xvGZc0ou05T8prMmFDm8t/+96uaXRWnQOL1d8oft6dqvCxXel1S/iQdIA0u es/languages/zephir.min.js
sha384-qMU7kAMFjac3vTfUVxn3MJNjbpzSvkv5Qt+QTKOm/6L/lJNjq5qrL2uDyqdbmwlp es/languages/powershell.min.js
sha384-vVIMPO482VU43+Qt0zZZyKZJbH6o8nswsJoI70cODQFCYGnGXQAyBFi2mRc84EI/ es/languages/gauss.min.js
sha384-CJBoRVas0OWkb0muREjJ03XpKdo+9syDQq1I8w/X8jLveor7xMRvccQH3N7WPDym languages/gml.min.js
sha384-ODO+OwRTM2US09Zi2DoJkcPzC2xhdKrJ85JKVMq/u7A9deYsuX65rcsJ51vLL2Gl es/languages/dust.min.js
sha384-XumNuSrHQ01kT/ZlM3new/EusMAaLGIP/0kbnjnmayfMjlavsgZMmaVI+LNlcmb4 es/languages/dts.min.js
sha384-/8jAsUSGLCC6y4ohluPoS3fNODjZQK6nHW8HH7z3DHe4BzyjDzkmMCztHaLnOMqi es/languages/mel.min.js
sha384-Cp3UdB3ve60wsXAgAC2b0OGtDtrCc9FNbmdkE6rzbzsHqWKE544GFA98yReqrnYI es/languages/pgsql.min.js
sha384-J7VhVOwKD+CCXZfCpMNduQdr0EZdIwxSktqk4SsXRhjlrBfFh1fAvEoG8/mqu3sG es/languages/stata.min.js
sha384-opv2hJqvMZgNBgnvi1KNXWtso0iIyASQ4VeM5X6w+E1wphTkNEgCPmdKWj8Dm6fy es/languages/x86asm.min.js
sha384-46ecOuNha4bgI4JrDybOfFJiSmHHcqCqlVnpUE/oJEZJI6Bm+dkjALUPiQi7Duxi languages/isbl.min.js
sha384-S+T17790aDj9unWEJneChlkrSG8sC33hf39C7GOXOctWx258mDlmMNPtkGVF32Fr es/languages/maxima.min.js
sha384-AtnUXm6o5bENCZL9+x3PrbviAQmox70hx+T8PLzdfiqM5hdn0ksRtaXdpDgNGPVp es/languages/sqf.min.js
sha384-O91FddlR95gI32FxvaRJptluF07GhrURRrINQs+7/3dY9qrDnlYU7E3Y0iYvbMrd es/languages/gml.min.js
sha384-v5nuZvkFnrTUM4l150F/yuI2c1UA59MPDdiCUVUeRTBz6esPV3ppDZpdVmALtw2w es/languages/isbl.min.js
sha384-JHxUWSSH1UPsVL6WjxFd+GSmxfsDH0yEIE2xClxc0l7xVQsDulr1wV8En3pUzKic es/languages/1c.min.js
sha384-3iE438GOhg7AwF7R2tYvCSAc9OXqqx4L8q/xdSJByq6CFL5KAxn1cfz42J5Y7hsC languages/arduino.min.js
sha384-NvOtUFcMsBylo+r555UF7YErPOx7CEwC6sJFP6XPtb9MgB4VjnnocPILeKM2Iebn languages/fsharp.min.js
sha384-XiSL3fCG43bdzKfpsJX49z6LA9/3Y/qT5prPmMCWwbpeGKpQjZNjFlAd8F+LFiOq languages/nsis.min.js
sha384-85U0nhRaxMH3lxr6lSBN0bYfP7fH9JSz66BVlntterQ0zbTa+td88A7eXPowxTbC languages/coffeescript.min.js
sha384-FFtfksoTAmQEdfkhz0W13XcothyKb6TtTNMDqT/uDVbb1w+wpb8yCJA/CYdKxANB languages/css.min.js
sha384-rKm8Bd6bZTjBvuHtqWLSG6xOzW5nKRoQE3uhxlpo61l9WqvouFwUP/bX5WjsCZYq languages/javascript.min.js
sha384-+pfUeaB6bKSi8fHlBrHRl1OW3u9uv5aJdczvPN7p2eRos0//QuiO84Jcd9g4Yhu2 languages/less.min.js
sha384-9j9mwVZ1HLR71hx89VH/V0IBymYvS3aWQqhcLkz9PbvYFNis7U/Gux2y2joUwsG9 languages/stylus.min.js
sha384-RBltkTfBbVREtpLpQ59SvjT0CWoOxIJxUA2m620YdsIYtsvFpwHiV3GG612VrjTW languages/scss.min.js
sha384-2hcw1m8Iz44YIRq2h49MMlG2AiEWg3lIOvp87s9yBDSttqAUFCyNz50x5x0rRvlr languages/livescript.min.js
sha384-Yjb8BYDCrWdb4Hg2wZe5KGO91HUNDOT5152vLtKpVz0jC3DFeURxhzbkDHc4k15G languages/kotlin.min.js
sha384-WeFQIdjcEdQFKSSJuYGQnsgV4/0Z45EKb+ce6JRP24KTqXDwIErdL1F0CaaYe6MT languages/java.min.js
sha384-w0dK9MZhtr5dsIFy+vEic+LGAK8p3dY9rwqUPXGmDlTYY3iSceay2tUDc6nFrfUy es/languages/arduino.min.js
sha384-n9QyKReY1xBcBSNLlDePkdsFwGZVOb9qBodbtv2S7V76pVknMqGEnpwDUT+QPfvR es/languages/fsharp.min.js
sha384-bPukuHin9BhbEydEGMNuc5u5zR6dTYejDPEV1uL4B1FVv0xeZ+Xl+gp4V6kZv/RM es/languages/nsis.min.js
sha384-n88w9GgiONTcB3Q8LDx09BonNGwWwdOWRHOcKEpr5RnEB1Owi/w4tFdyxFc7oIAl es/languages/coffeescript.min.js
sha384-h+epqh+PaYIAVFSCCOrAMh8q104j5Qi4E6tlJ1Vv1z/DLvIFa0h/c0Yb8LOjgYYj es/languages/css.min.js
sha384-dYn3Ikj5UFy4/yusx2dHwqA4SL+ugIol5tRsbIwvdG+DPSNeM2HdB1n97mpyB7hk es/languages/javascript.min.js
sha384-PuBSyfOTpjNdrO2DLLszzP4Fj3QIJnzZE/IRWtk0yvgIMRtsAxbeKly3FL2IYkvH es/languages/less.min.js
sha384-DO6BboNv2jaTxVZtw8HhIdjZrOq9g1xwhwnEIjj6croFVz4oQthxApMlnWprmDpg es/languages/stylus.min.js
sha384-4MAr3T8eb+DGq4xuAJZSZ//ZGah0q3BwULK9I5FlN4YAsiq77rHiNw0qUMM1LD1n es/languages/scss.min.js
sha384-oEQdylazgYlYqybJHFFDyy0T+Hvx7ApKJ0jT8CQVnYhLIcrHd9VDh/JC09gDJgRf es/languages/livescript.min.js
sha384-5WFkBPvW4S27AUR8IZQfyyxYBKWdcNNH3AebLhc2M6wu1p1wPWbvtIAI3omfxVEI es/languages/kotlin.min.js
sha384-63gQ0OiPcRhbP7WuxpH49G1tPRZuz+U2KvQmAHP4jvuPyxCJa/NBASXXH6WREinQ es/languages/java.min.js
sha384-OXmKpj99/+7Pw4yl0594dcKU2St8sdpseQ8W20nZGR6l60gDNX92PwIWkxmM2q6d languages/mathematica.min.js
sha384-zT6+E1C0fZD5KO31ynKYOKJysLzJpSiFjZ1GkNniYgRke74Lr85QramWyrbdvnZq es/languages/mathematica.min.js
sha384-olHzySS+kmDA/YmPohhIMIiJQUE7DhLNhp80oY5Brld6b+ukiLTV4C5UE5RMtcJH languages/swift.min.js
sha384-tsSjvUTraCwcMDjEEL5RVnLF0ImkgxKE8dTQBFpcfPiY0uVBMNDRASyjoncecXHl languages/typescript.min.js
sha384-CE1qCnWBcr7IHiBfK6bN4lNjqLhUeuMhadD7wzCdisPafXjwBxrgdaOvjlCGFV1m es/languages/swift.min.js
sha384-ub2atnkSGPEe1/jDaIcICqQX8rsEn9eDMh1/pG447K8HfNFn835C1scaKhTiekOZ es/languages/typescript.min.js
```
